


capture log close


/*This do file creates the tables and figures in:

Abate, de Brauw, Gibson, Hirvonen, and Wolle. "Telescoping Error in Recalled Food Consumption: Evidence from a Survey Experiment in Ethiopia", published in the World Bank Economic Review.


*/

	*set global for data folder address:
	global user "`c(username)'"

	global data		"C:/Users/${user}\Dropbox (IFPRI)\research\Ethiopia_telescoping_experiment\drafts\WBER\replication_files\data"
	global results 	"C:/Users/${user}\Dropbox (IFPRI)\research\Ethiopia_telescoping_experiment\drafts\WBER\replication_files\results"
	global logfile 	"C:/Users/${user}\Dropbox (IFPRI)\research\Ethiopia_telescoping_experiment\drafts\WBER\replication_files\log"
	
*start logging:

log using "$logfile\Abate_et_al_WBER_telescoping.log", replace

*Stata version:
version 17


/*

This do file produces the results reported in:

Abate, de Brauw, Gibson, Hirvonen, and Wolle. "Telescoping Error in Recalled Food Consumption: Evidence from a Survey Experiment in Ethiopia", published in the World Bank Economic Review.

*/
	
	
use "$data/telescoping_experiment_hh_data_anon.dta", clear
isid HH_ID
 

*set globals for the regression
global treat unbounded
global controls hhsize head_male head_educ
global othertreat T_2 T_3	
	
	
*report consumption values in adult equivalent terms (instead of per capita)
foreach v of newlist fexp kcal prot {
gen `v'_aeu=`v'_pc*hhsize/heq
	
	
} 	

*For the text in section 2:
	
	assert resp_male!=.
	gen female_respondent=resp_male==0
	label var female_respondent "Female respondent"
	tab female_respondent
	*91.73 %
	
	*mean per capita amounts in control group:
	sum fexp_pc kcal_pc prot_pc if unbounded==0 & outlier==0

	*mean per adult equivalent amounts in control group:
	sum fexp_aeu kcal_aeu prot_aeu if unbounded==0 & outlier==0

	*these are no longer needed:
	drop *_aeu	
	
**********************************************************************************************************
*Table 2. Household characteristics, by recall type
**********************************************************************************************************
*we need this user-written command:
ssc install ietoolkit, replace

iebaltab female_respondent $controls heq asset_index T_1 $othertreat bl_fexp_pc    if outlier!=1, grpvar(unbounded)  vce(cluster cluster) save("$results/table_2_balance") replace   onenrow rowvarlabel pttest  star(0.05 0.01 0.001)


  
**********************************************************************************************************
*Figure 1. Distribution of (ln) weekly food consumption per capita (in birr), by recall type
**********************************************************************************************************
twoway (kdensity lnfexp_pc if   outlier!=1 & unbounded==0, lcolor(gs7) lwidth(medthick) lpattern(dash)) (kdensity lnfexp_pc if   outlier!=1 & unbounded==1, lcolor(maroon) lwidth(medthick) lpattern(solid)), ytitle(Kernel density) ytitle(, margin(medsmall)) xtitle("(ln) total weekly food consumption per capita (in birr)", margin(medium)) legend(order(1 "Bounded" 2 "Unbounded recall") region(lcolor(none)) position(12)) scheme(s1color)	  ylabel(0(0.2)1)
graph export "$results/figure_1_kernel_density_expenditure.tif", replace width(1200)  
	
	 
**********************************************************************************************************
*Table 3. Impact of unbounded recall on weekly per capita food consumption (in birr)
**********************************************************************************************************
 
*birr consumption in levels:
	reg fexp_pc  $treat if outlier!=1, cluster(cluster)
	estimates store r1
	*control for hh level chars and treatment status in the other study + sub-city fixed effects:
	reg fexp_pc  $treat $controls $othertreat  i.sub_city if outlier!=1, cluster(cluster)
	estimates store r2

*birr consumption in logs:
	reg lnfexp_pc  $treat if outlier!=1, cluster(cluster)
	estimates store r3
	*control for hh level chars and treatment status in the other study + sub-city fixed effects:
	reg lnfexp_pc  $treat $controls $othertreat  i.sub_city if outlier!=1, cluster(cluster)
	estimates store r4
	
	*Exact interpretation:
	local coef1=_b[unbounded]
	local var1=(_se[unbounded])^2
	di `coef1'

	di `var1'
	
 	di (exp(`coef1'-0.5*`var1')-1)*100
	
	
	*Let's do confidence intervals manually:
 
	
	di (exp(0.0726071-0.5*`var1')-1)*100
	di (exp(0.2314513-0.5*`var1')-1)*100	 

	
esttab r1 r2 r3 r4 using "$results/table_3_main_results.rtf", nogaps r2  se label star(+ 0.10 * 0.05 ** 0.01 *** 0.001) title("Table 3. Impact of unbounded recall on weekly per capita food consumption (in birr)") replace  b(%9.3f)   mtitles("Unconditional" "Conditional" "Unconditional" "Conditional") keep($treat)

sum fexp_pc lnfexp_pc if outlier!=1 & unbounded==0

**********************************************************************************************************
*Table 4. Impact of unbounded recall on (log) daily per capita calorie and protein intakes
**********************************************************************************************************
 
*kcal consumption in logs:
	reg lnkcal_pc  $treat if outlier!=1, cluster(cluster)
	estimates store r1
	*control for hh level chars and treatment status in the other study + sub-city fixed effects:
	reg lnkcal_pc  $treat $controls $othertreat  i.sub_city if outlier!=1, cluster(cluster)
	estimates store r2
	*Exact interpretation:
	local coef1=_b[unbounded]
	local var1=(_se[unbounded])^2
	di `coef1'
	di `var1'
	
 	di (exp(`coef1'-0.5*`var1')-1)*100
	
	*Let's do confidence intervals manually:
 	di (exp(0.0308301-0.5*`var1')-1)*100
	di (exp(0.1377454-0.5*`var1')-1)*100	
	
*protein consumption in logs:
	reg lnprot_pc  $treat if outlier!=1, cluster(cluster)
	estimates store r3
	*control for hh level chars and treatment status in the other study + sub-city fixed effects:
	reg lnprot_pc  $treat $controls $othertreat  i.sub_city if outlier!=1, cluster(cluster)
	estimates store r4
	*Exact interpretation:
	local coef1=_b[unbounded]
	local var1=(_se[unbounded])^2
	di `coef1'
	di `var1'
	
 	di (exp(`coef1'-0.5*`var1')-1)*100
	
	*Let's do confidence intervals manually:
 	di (exp(0.0767605-0.5*`var1')-1)*100
	di (exp(0.2194018-0.5*`var1')-1)*100	
	
 
esttab r1 r2 r3 r4 using "$results/table_4_calories_protein.rtf", nogaps r2  se label star(+ 0.10 * 0.05 ** 0.01 *** 0.001) title("Table 4. Impact of unbounded recall on (log) daily per capita calorie and protein intakes")replace  b(%9.3f)   mtitles("Unconditional" "Conditional" "Unconditional" "Conditional") keep($treat)

sum lnkcal_pc lnprot_pc if outlier!=1 & unbounded==0


**********************************************************************************************************
*Table 5. Impact of unbounded recall on household diet diversity (HDDS) and food consumption scores (FCS)
**********************************************************************************************************
 
*FANTA HDDS:
	reg HDDS  $treat if outlier!=1, cluster(cluster)
	estimates store r1
	*control for hh level chars and treatment status in the other study + sub-city fixed effects:
	reg HDDS  $treat $controls $othertreat  i.sub_city if outlier!=1, cluster(cluster)
	estimates store r2
 
*WFP FCS:
	reg FCS_score   $treat if outlier!=1, cluster(cluster)
	estimates store r3
	*control for hh level chars and treatment status in the other study + sub-city fixed effects:
	reg FCS_score   $treat $controls $othertreat  i.sub_city if outlier!=1, cluster(cluster)
	estimates store r4
	

esttab r1 r2 r3 r4 using "$results/table_5_HDDS_FCS.rtf", nogaps r2  se label star(+ 0.10 * 0.05 ** 0.01 *** 0.001) title("Table 5. Impact of unbounded recall on household diet diversity (HDDS) and food consumption scores (FCS)")replace  b(%9.3f) mtitles("Unconditional" "Conditional" "Unconditional" "Conditional") keep($treat)
	
sum HDDS FCS_score if outlier!=1 & unbounded==0

**********************************************************************************************************
*Table 6. Impact of unbounded recall on consumption of different food groups
**********************************************************************************************************

*Panel A. Dependent variable: =1 if consumed from the food group, zero otherwise
********************************************************************************
 
	sum fexp_staple_YN fexp_legum_YN fexp_veg_YN fexp_fruit_YN fexp_meat_YN fexp_dairy_YN fexp_oth_YN
	*NOTE: not enough variation for staples, vegs and other

	global y fexp_staple_YN 
	reg $y  $treat $controls $othertreat  i.sub_city if outlier!=1, cluster(cluster)
	estimates store r1

	global y fexp_legum_YN 
	reg $y  $treat $controls $othertreat  i.sub_city if outlier!=1, cluster(cluster)
	estimates store r2

	global y fexp_veg_YN 
	reg $y  $treat $controls $othertreat  i.sub_city if outlier!=1, cluster(cluster)
	estimates store r3

	global y fexp_fruit_YN 
	reg $y  $treat $controls $othertreat  i.sub_city if outlier!=1, cluster(cluster)
	estimates store r4

	global y fexp_meat_YN 
	reg $y  $treat $controls $othertreat  i.sub_city if outlier!=1, cluster(cluster)
	estimates store r5

	global y fexp_dairy_YN 
	reg $y  $treat $controls $othertreat  i.sub_city if outlier!=1, cluster(cluster)
	estimates store r6

	global y fexp_oth_YN
	reg $y  $treat $controls $othertreat  i.sub_city if outlier!=1, cluster(cluster)
	estimates store r7


	sum fexp_staple_YN fexp_legum_YN fexp_veg_YN fexp_fruit_YN fexp_meat_YN fexp_dairy_YN fexp_oth_YN if outlier!=1 & unbounded==0, separator(0)

esttab r1 r2 r3 r4 r5 r6 r7 using "$results/table_6_panel_A.rtf", nogaps r2  se label star(+ 0.10 * 0.05 ** 0.01 *** 0.001) title("Table 6. Panel A")replace  b(%9.3f) mtitles("Staples" "Legumes" "Vegetables" "Fruit" "Meat" "Dairy" "Other") keep($treat) 

*Panel B. Dependent variable: Number of days consumed from the food group
********************************************************************************
 
	sum *_fr
	*NOTE: not enough variation for staples, vegs & other

	global y fexp_staple_fr 
	reg $y  $treat $controls $othertreat  i.sub_city if outlier!=1, cluster(cluster)
	estimates store r1

	global y fexp_legum_fr 
	reg $y  $treat $controls $othertreat  i.sub_city if outlier!=1, cluster(cluster)
	estimates store r2

	global y fexp_veg_fr 
	reg $y  $treat $controls $othertreat  i.sub_city if outlier!=1, cluster(cluster)
	estimates store r3

	global y fexp_fruit_fr 
	reg $y  $treat $controls $othertreat  i.sub_city if outlier!=1, cluster(cluster)
	estimates store r4

	global y fexp_meat_fr 
	reg $y  $treat $controls $othertreat  i.sub_city if outlier!=1, cluster(cluster)
	estimates store r5

	global y fexp_dairy_fr 
	reg $y  $treat $controls $othertreat  i.sub_city if outlier!=1, cluster(cluster)
	estimates store r6

	global y fexp_oth_fr
	reg $y  $treat $controls $othertreat  i.sub_city if outlier!=1, cluster(cluster)
	estimates store r7


	sum *_fr if outlier!=1 & unbounded==0, separator(0)

esttab r1 r2 r3 r4 r5 r6 r7 using "$results/table_6_panel_B.rtf", nogaps r2  se label star(+ 0.10 * 0.05 ** 0.01 *** 0.001) title("Table 6. Panel B")replace  b(%9.3f) mtitles("Staples" "Legumes" "Vegetables" "Fruit" "Meat" "Dairy" "Other") keep($treat) 

*Panel C. Dependent variable: birr value consumed from the food group
********************************************************************************

	sum fexp_staple fexp_legum fexp_veg fexp_fruit fexp_meat fexp_dairy fexp_oth 

	global y fexp_staple 
	reg $y  $treat $controls $othertreat  i.sub_city if outlier!=1, cluster(cluster)
	estimates store r1

	global y fexp_legum 
	reg $y  $treat $controls $othertreat  i.sub_city if outlier!=1, cluster(cluster)
	estimates store r2

	global y fexp_veg 
	reg $y  $treat $controls $othertreat  i.sub_city if outlier!=1, cluster(cluster)
	estimates store r3

	global y fexp_fruit 
	reg $y  $treat $controls $othertreat  i.sub_city if outlier!=1, cluster(cluster)
	estimates store r4

	global y fexp_meat 
	reg $y  $treat $controls $othertreat  i.sub_city if outlier!=1, cluster(cluster)
	estimates store r5

	global y fexp_dairy 
	reg $y  $treat $controls $othertreat  i.sub_city if outlier!=1, cluster(cluster)
	estimates store r6

	global y fexp_oth
	reg $y  $treat $controls $othertreat  i.sub_city if outlier!=1, cluster(cluster)
	estimates store r7

	sum fexp_staple fexp_legum fexp_veg fexp_fruit fexp_meat fexp_dairy fexp_oth if outlier!=1 & unbounded==0, separator(0)

esttab r1 r2 r3 r4 r5 r6 r7 using "$results/table_6_panel_C.rtf", nogaps r2  se label star(+ 0.10 * 0.05 ** 0.01 *** 0.001) title("Table 6. Panel C")replace  b(%9.2f) mtitles("Staples" "Legumes" "Vegetables" "Fruit" "Meat" "Dairy" "Other") keep($treat)  
 
**********************************************************************************************************
*Figure 2: telescoping bias vs consumption frequency
**********************************************************************************************************
 
*switch to item level data:
use "$data\telescoping_experiment_item_data_anon.dta", clear
	isid HH_ID food_item
	*omit outliers:
	drop if outlier==1
	 
	gen n=1 if days>0
	gen price=fexp/quant

	
	collapse (mean) days price  (sum) n, by(food_item FG) 

	gen avgdays=days
	label var avgdays "mean number of days consumed"
	drop days

	tempfile avgdays
	save `avgdays'


	use "$data\telescoping_experiment_item_data_anon.dta", clear
	isid HH_ID food_item

	
	drop if outlier==1
	*average consumption value for each food item -- separately for the 2 recall groups: 
	
	gen YN=fexp>0 if fexp!=.

	
	collapse (mean) fexp_pc YN ,by(food_item unbounded)

	reshape wide fexp_pc YN, i(food_item) j(unbounded)
	
	gen ratio=fexp_pc1/fexp_pc0
	label var ratio "ratio of unbounded to bounded recall"
	
	gen ratioYN=YN1/ YN0
	label var ratio "ratio of unbounded to bounded recall YN screening question"
	sum *YN*
	merge 1:1 food_item using  `avgdays'
	assert _m==3
	drop _m
	count
 	*the group specific means are never zero if we ignore items consumed by less than 5 % of the households:
	assert fexp_pc0!=0  if n>=45
	assert fexp_pc1!=0  if n>=45


	count

*test discussed in footnote #25:
	sort food_item
	gen order=_n
	sum order
	reg ratioYN order, robust	
	

 
	
*FIGURE 2:	
	
*put more weight on more expensive items & ignore food items that were consumed by less than 5 % of the households:
twoway (scatter ratio avgdays if n>=45, mcolor(edkblue) msize(6-pt) msymbol(circle_hollow)) (lfitci ratio avgdays [aweight = price] if n>=45, lcolor(black) fcolor(gs8%40)alcolor(%0)), ytitle("ratio of unbounded to bounded recall", margin(medsmall)) yline(1, lpattern(dash) lcolor(black)) ylabel(0(0.5)3.0, format(%2.1f)) xtitle("mean number of days consumed", margin(medsmall)) xlabel(0(1)7)  legend(order(1 "food item" 3 "fitted line"  2 "95% CI") rows(1) region(lcolor(none))position(12)) scheme(s1color)
graph export "$results/figure_2_ratio_weighted.tif", replace width(1200)  
count if n>=45
 
 

*Figure S2.1. Replicating Figure 2 without regression weights
*************************************************************

twoway (scatter ratio avgdays if n>=45, mcolor(edkblue) msize(6-pt) msymbol(circle_hollow)) (lfitci ratio avgdays if n>=45, lcolor(black) fcolor(gs8%40)alcolor(%0)), ytitle("ratio of unbounded to bounded recall", margin(medsmall)) yline(1, lpattern(dash) lcolor(black)) ylabel(0(0.5)3.0, format(%2.1f)) xtitle("mean number of days consumed", margin(medsmall)) xlabel(0(1)7)  legend(order(1 "food item" 3 "fitted line"  2 "95% CI") rows(1) region(lcolor(none))position(12)) scheme(s1color)
graph export "$results/figure_S2_1_ratio_notweighted.tif", replace width(1200)  
count if n>=45
 

*Figure S2.2. Replicating Figure 2 but using a larger set of food items and winsorizing the ratio of unbounded recall to bounded recall value
*********************************************************************************************************************************************
 	drop if fexp_pc0==0 //not defined
	drop if fexp_pc1==0 //not defined

	sum ratio, det
	replace ratio=`r(p95)' if ratio>`r(p95)'
	replace ratio=`r(p5)' if ratio<`r(p5)'
	

count
twoway (scatter ratio avgdays, mcolor(edkblue) msize(6-pt) msymbol(circle_hollow)) (lfitci ratio avgdays [aweight = price], lcolor(black) fcolor(gs8%40)alcolor(%0)), ytitle("ratio of unbounded to bounded recall", margin(medsmall)) yline(1, lpattern(dash) lcolor(black)) ylabel(0(0.5)3.0, format(%2.1f)) xtitle("mean number of days consumed", margin(medsmall)) xlabel(0(1)7)  legend(order(1 "food item" 3 "fitted line"  2 "95% CI") rows(1) region(lcolor(none))position(12)) scheme(s1color)
graph export "$results/figure_S2_2_ratio_winsorized.tif", replace width(1200)  


 
********************************************************************************************************** 
*Table 7. Regression results from interaction models 
**********************************************************************************************************

use "$data/telescoping_experiment_hh_data_anon.dta", clear
	isid HH_ID

	global y lnfexp_pc
	global controls hhsize head_male head_educ


	
	gen interaction=unbounded*head_male
	reg $y   unbounded interaction $controls i.sub_city if outlier!=1, cluster(cluster)
	estimates store r1
	drop interaction
	
	gen interaction=unbounded*head_educ
	reg $y   unbounded interaction $controls i.sub_city if outlier!=1, cluster(cluster)
	estimates store r2
	drop interaction
	
	gen interaction=unbounded*hhsize
	reg $y   unbounded interaction $controls i.sub_city if outlier!=1, cluster(cluster)
	estimates store r3
	
	reg $y   unbounded interaction $controls i.sub_city if outlier!=1 & hhsize<=8, cluster(cluster)
	estimates store r4	
 
esttab r1 r2 r3 r4 using "$results/table_7_heterogeneity.rtf", nogaps r2  se label star(+ 0.10 * 0.05 ** 0.01 *** 0.001) title("Table 7. Regression results from interaction models")replace  b(%9.3f)  keep(unbounded interaction)
 
 
**********************************************************************************************************
* Adjustment factors and mean-reverting error patterns (only reported in the text; no table/figure)
**********************************************************************************************************

use "$data/telescoping_experiment_hh_data_anon.dta", clear
isid HH_ID

	*compute cluster-averages:
	unique cluster
	*40 clusters

	foreach v of varlist  lnfexp_pc lnkcal_pc {
	gen `v'0=`v' if unbounded==0
	gen `v'1=`v' if unbounded==1

	}
	drop if outlier==1
	collapse (mean) lnfexp_pc? lnkcal_pc? ,by(  cluster)

	reg  lnfexp_pc0 lnfexp_pc1, robust
	test _b[lnfexp_pc1]==1

	
	
**************************************************************************************************************************** 
* Appendix B
****************************************************************************************************************************
  

*Table S2.1. Replicating Column 4 in Table 3 but including the five households with implausibly high consumption values and using non-winsorized consumption data
*************************************************************************************************************************************************************
	
use "$data/telescoping_experiment_hh_data_anon.dta", clear
isid HH_ID 
 

*birr consumption in logs:
 
	*All households:
	reg lnfexp_pc  $treat $controls $othertreat  i.sub_city   , cluster(cluster)
	estimates store r1
	
	*Non-winsorized:
	reg nw_lnfexp_pc  $treat $controls $othertreat  i.sub_city if outlier!=1, cluster(cluster)
	estimates store r2
	
 
esttab r1 r2   using "$results/table_S2_1_allHHs_non_wind.rtf", nogaps r2  se label star(+ 0.10 * 0.05 ** 0.01 *** 0.001) title("Table S2.1. Replicating Column 4 in Table 3 but including the five households with implausibly high consumption values and using non-winsorized consumption data") replace  b(%9.3f)   mtitles("All households" "Non-winsorized") keep($treat)

 

*Table S2.2. Replicating Column 4 in Table 3 using quantile regressions
*************************************************************************************************************************************************************


*bootstrapped standard errors, 500 repetitions
*25, 50 75 quantiles + interquantile test for differences between 25 and 75 quantile

*set seed using the first 4 digits from here: https://twitter.com/dailyrandomnums/status/1263378505938751488 (today's date)
set seed 2106 


global y lnfexp_pc
	d $y
	local label : variable label $y

	bsqreg  $y  $treat  $othertreat $controls  i.sub_city if outlier!=1, quantile(0.25) reps(500)
	estimates store q25, title(q25)

	bsqreg  $y  $treat   $othertreat $controls  i.sub_city if outlier!=1, quantile(0.50) reps(500)
	estimates store q50, title(q50)

	bsqreg  $y  $treat    $othertreat $controls  i.sub_city if outlier!=1, quantile(0.75) reps(500)
	estimates store q75, title(q75)

	iqreg  $y  $treat  $othertreat $controls  i.sub_city if outlier!=1, quantile(.25 .75) reps(500)
	estimates store iq25_75, title(iq25_75)

esttab q25 q50 q75 iq25_75 using "$results/table_S2_2_quantile_regs.rtf", nogaps r2 ar2  se label star(+ 0.10 * 0.05 ** 0.01 *** 0.001) title("`label'") replace  b(%9.3f)    mtitles("25th q" "50th q" "75th q" "25q vs 75q")  addnotes("note: bootstrapped standard errors (500 repetitions)") 




*Table S2.3. Interacting survey experiment status with video treatment status
*************************************************************************************************************************************************************
 
 
 gen unboundedXT_2=unbounded*T_2
 gen unboundedXT_3=unbounded*T_3
 
	*control for hh level chars and treatment status in the other study + sub-city fixed effects:
	
	reg lnfexp_pc  $treat   $othertreat $controls     if outlier!=1, cluster(cluster)
	estimates store r1a
	
	reg lnfexp_pc  $treat  unboundedXT_2 unboundedXT_3 $othertreat $controls     if outlier!=1, cluster(cluster)
	estimates store r1b
	
	
	reg lnkcal_pc  $treat   $othertreat  $controls  if outlier!=1, cluster(cluster)
	estimates store r2a

	reg lnkcal_pc  $treat  unboundedXT_2 unboundedXT_3 $othertreat  $controls  if outlier!=1, cluster(cluster)
	estimates store r2b
	
	
	reg lnprot_pc  $treat  $othertreat  $controls  if outlier!=1, cluster(cluster)
	estimates store r3a	
	
	reg lnprot_pc  $treat  unboundedXT_2 unboundedXT_3 $othertreat  $controls  if outlier!=1, cluster(cluster)
	estimates store r3b		
	 
	
esttab r1a r1b r2a r2b r3a r3b   using "$results/table_S2_3_video_interactions.rtf", nogaps r2  se label star(+ 0.10 * 0.05 ** 0.01 *** 0.001) title("Table S2.3. Interacting survey experiment status with video treatment status") replace  b(%9.3f)   keep($treat  unboundedXT_2 unboundedXT_3 T_2 T_3)

****************************************************************************************************************************
*Appendix C. Benford’s Law Analysis
****************************************************************************************************************************
	*We need these user-written commands:
	ssc install digdis, replace
	ssc install moremata, replace
	ssc install mgof, replace

	use "$data\telescoping_experiment_item_data_anon.dta", clear
	isid HH_ID food_item
	drop if raw_quant==0
	unique food_item

 
	 
*Table S3.1. Predicted and observed first-digit distribution, Bounded and Unbounded Recall Groups
*************************************************************************************************************************************************************
	
 
	digdis raw_quant, by(unbounded) percent     
  	
	*Table S3.1 was manually compiled from the output above
	 
	 
	keep if unbounded==0
 		
	digdis raw_quant, percent by(food_item) generate(digs) notest nofreq 
	
	
	foreach v of numlist 1/9 {
	gen d`v'=digs==`v'
	}
	gen n=1
	*collapse to food item level
	collapse (sum) d? n, by(food_item)

	egen all=rowtotal(d?)


	foreach v of numlist 1/9 {
	gen p`v'=100*d`v'/all
	}

	*expected percentages:
	gen	ben1=	30.103
	gen	ben2=	17.609
	gen	ben3=	12.494
	gen	ben4=	9.691
	gen	ben5=	7.918
	gen	ben6=	6.695
	gen	ben7=	5.799
	gen	ben8=	5.115
	gen	ben9=	4.576

	*calculate euclidean distance:

	gen dist = (p1-ben1)^2 + (p2-ben2)^2 + (p3-ben3)^2 + (p4-ben4)^2 + (p5-ben5)^2 + (p6-ben6)^2 + (p7-ben7)^2 + (p8-ben8)^2 + (p9-ben9)^2
	replace dist=sqrt(dist)
	keep dist food_item  n
	gen unbounded=0
	tempfile temp
	save `temp'

	*unbounded method:
	use "$data\telescoping_experiment_item_data_anon.dta", clear
 	keep if unbounded==1
	drop if raw_quant==0

	digdis raw_quant, percent by(food_item) generate(digs) notest nofreq

	foreach v of numlist 1/9 {
	gen d`v'=digs==`v'
	}
	gen n=1
	collapse (sum) d? n, by(food_item)

	egen all=rowtotal(d?)


	foreach v of numlist 1/9 {
	gen p`v'=100*d`v'/all
	}

	*expected percentages:
	gen	ben1=	30.103
	gen	ben2=	17.609
	gen	ben3=	12.494
	gen	ben4=	9.691
	gen	ben5=	7.918
	gen	ben6=	6.695
	gen	ben7=	5.799
	gen	ben8=	5.115
	gen	ben9=	4.576

	*calculate euclidean distance:

	gen dist = (p1-ben1)^2 + (p2-ben2)^2 + (p3-ben3)^2 + (p4-ben4)^2 + (p5-ben5)^2 + (p6-ben6)^2 + (p7-ben7)^2 + (p8-ben8)^2 + (p9-ben9)^2
	replace dist=sqrt(dist)
 
	keep dist food_item n
	gen unbounded=1
	 
	append using  `temp'

	duplicates tag food_item, gen(tag)
	tab tag
	*drop items that do not appear for both groups:
	keep if tag==1
	
	unique food_item
	 *33 different units
	sum dist
	gen ndist=(dist-r(mean))/r(sd) 

*Table S3.2. Testing differences in Euclidean distance to the distribution predicted by Benford's law
*************************************************************************************************************************************************************	
 	reg ndist unbounded, robust  
	estimates store r1

 	xtreg ndist unbounded, fe i (food_item)  
	estimates store r2

preserve	
	keep if n>=20
	reg ndist unbounded, robust  
	estimates store r3
	
 	xtreg ndist unbounded, fe i (food_item)  
	estimates store r4
restore	
	
esttab r1 r2 r3 r4 using "$results/table_S3_2_benfords_law_test.rtf", nogaps r2  se label star(+ 0.10 * 0.05 ** 0.01 *** 0.001) title("Table S3.2. Testing differences in Euclidean distance to the distribution predicted by Benford's law")replace  b(%9.3f)  keep(unbounded)



 
**********************************************************************************************************
*Table S2.4. Replicating Table 3 using ANCOVA specification
**********************************************************************************************************
 

use "$data/telescoping_experiment_hh_data_anon.dta", clear
isid HH_ID

	
*set globals for the regression
global treat unbounded
global controls hhsize head_male head_educ
global othertreat T_2 T_3	
	
 
*birr consumption in levels:
label var bl_fexp_pc "Baseline per capita consumption"

	reg fexp_pc  $treat bl_fexp_pc if outlier!=1, cluster(cluster)
	estimates store r1
	*control for hh level chars and treatment status in the other study + sub-city fixed effects:
	reg fexp_pc  $treat bl_fexp_pc $controls $othertreat  i.sub_city if outlier!=1, cluster(cluster)
	estimates store r2

		
*birr consumption in logs:

gen ln_bl_fexp_pc=ln(bl_fexp_pc)
label var ln_bl_fexp_pc "(log) Baseline per capita consumption"

	reg lnfexp_pc  $treat ln_bl_fexp_pc if outlier!=1, cluster(cluster)
	estimates store r3
	*control for hh level chars and treatment status in the other study + sub-city fixed effects:
	reg lnfexp_pc  $treat ln_bl_fexp_pc $controls $othertreat  i.sub_city if outlier!=1, cluster(cluster)
	estimates store r4
	
 	
esttab r1 r2 r3 r4 using "$results/table_S2_4_ANCOVA_specification.rtf", nogaps r2  se label star(+ 0.10 * 0.05 ** 0.01 *** 0.001) title("Table S2.4. Replicating Table 3 using ANCOVA specification") replace  b(%9.3f)   mtitles("Unconditional" "Conditional" "Log+Unconditional" "Log+Conditional") keep($treat *bl_fexp_pc)

 



*the end

 


log close

 
	 